/// <reference types="i18next" />
import type { ComponentType } from 'react';
import type { EditorState } from 'draft-js';
import type { ComponentData, ModalStyles, TranslationFunction, Pubsub, GetEditorBounds, ButtonType, ModifierKey, ToolbarType, ModalDecorations, LegacyEditorPluginConfig, SetEditorState, GetEditorState, AvailableExperiments } from '.';
export declare type InlineButton = {
    type: ButtonType;
    keyName: string;
    icon?: (props: any) => JSX.Element;
    mobile?: boolean;
    mapComponentDataToButtonProps?: (componentData: ComponentData) => Partial<InlineButton>;
    tooltipTextKey?: string;
    multiple?: boolean;
    onFilesSelected?: (pubsub: Pubsub, files: File[]) => void;
    panelContent?: ComponentType;
    min?: number;
    max?: number;
    inputMax?: number;
    modalName?: string;
    modalStyles?: ModalStyles;
    t?: TranslationFunction;
    anchorTarget?: string;
    relValue?: string;
    disabled?: boolean;
    desktop?: boolean;
    getEditorBounds?: GetEditorBounds;
};
export declare type ToolbarButtonProps = {
    type?: string;
    tooltip?: string;
    toolbars?: ToolbarType[];
    getIcon?: () => ComponentType;
    getLabel?: () => string;
    onClick?: (e: any & {
        ref?: any;
        render?: any;
    }) => void;
    isActive?: () => boolean;
    isDisabled?: () => boolean;
    onChange?: (files: File[]) => void;
    accept?: string;
    multiple?: boolean;
    dataHook?: string;
    name?: string;
};
export declare type InsertButton = ToolbarButtonProps & {
    name: string;
    componentData?: ComponentData;
    modalElement?: ComponentType;
    modalStyles?: ModalStyles;
    modalStylesFn?: (params: {
        buttonRef: HTMLElement;
        toolbarName: ToolbarType;
        pubsub?: Pubsub;
    }) => ModalStyles;
    section?: string;
    modalName?: string;
    modalDecorations?: ModalDecorations;
    multi?: boolean;
    addBlockHandler?: (editorState: EditorState) => void;
};
export declare type CreateInlineButtons = (config?: any) => InlineButton[];
export declare type CreateInsertButtons = (config?: any) => InsertButton[];
export declare type CommandHandler = (editorState: EditorState, event?: Event) => EditorState | void;
export interface KeyCommand {
    command: string;
    modifiers?: ModifierKey[];
    key: string;
    keyCode?: number;
}
export declare type KeyBinding = {
    keyCommand: KeyCommand;
    commandHandler: CommandHandler;
};
export interface TextButtonMapping {
    component?: ComponentType;
    isMobile?: boolean;
    position?: {
        mobile?: number;
        desktop?: number;
    };
    keyBindings?: KeyBinding[];
    externalizedButtonProps?: ToolbarButtonProps;
}
export declare type PluginTextButtons = {
    [buttonName: string]: TextButtonMapping;
};
export declare type TextButtonMapper = (pubsub?: Pubsub) => PluginTextButtons;
export interface PluginKeyBindings {
    commands: KeyCommand[];
    commandHandlers: Record<string, CommandHandler>;
}
export declare type CreatePluginToolbar = (config: any) => {
    name: string;
    InlineButtons?: InlineButton[];
    InlinePluginToolbarButtons?: InlineButton[];
    InsertButtons?: InsertButton[];
    TextButtonMapper?: TextButtonMapper;
    isMobile?: boolean;
};
export interface ButtonProps {
    buttons: string[];
    textPluginButtons: TextButtonMapping[];
    defaultTextAlignment: string;
    t: TranslationFunction;
    config: LegacyEditorPluginConfig;
    setEditorState: SetEditorState;
    getEditorState: GetEditorState;
    experiments: AvailableExperiments;
}
//# sourceMappingURL=buttonTypes.d.ts.map