/// <reference types="i18next" />
import type { CSSProperties, ComponentType } from 'react';
import type { Styles as ReactModalStyles } from 'react-modal';
import type { ComponentData, DraftContent, RicosEntity } from 'ricos-content';
import type { DecorationMode, TranslationFunction, Helpers, LegacyEditorPluginConfig, LegacyViewerPluginConfig } from '.';
import type { BoundingRect } from 'react-measure';
import type { ContentBlock, SelectionState, EditorState } from 'draft-js';
export { Link_Rel } from 'ricos-schema';
export type { Pubsub, Store } from '../Utils/simplePubsub';
export declare type ModalStyles = ReactModalStyles;
export declare type Styles = Record<string, CSSProperties>;
export declare type RichContentTheme = {
    [propName: string]: any;
    modalTheme?: ModalStyles;
};
export declare type ClassNameStrategy = (componentData: ComponentData, theme: RichContentTheme, styles: Record<string, string>, isMobile: boolean, innerRCERenderedIn: string) => string;
export declare type ContainerClassNameStrategy = (theme: RichContentTheme) => string;
export type { TranslationFunction, ResourceKey as LocaleResource } from 'i18next';
export declare type AnchorTarget = HTMLAnchorElement['target'];
export declare type RelValue = HTMLAnchorElement['rel'];
export declare type CustomAnchorScroll = (event: Event, anchor: string) => void;
export declare type GetEditorBounds = () => BoundingRect | undefined;
export declare type OpenModalFunction = (data: Record<string, unknown>) => void;
export declare type CloseModalFunction = () => void;
export declare type InnerModalType = {
    openInnerModal: OpenModalFunction;
    closeInnerModal: CloseModalFunction;
};
export declare type ModalDecorations = {
    decorationMode: DecorationMode;
    decorator: ComponentType;
}[];
export declare type OnConfirmFunction = (data: any) => {
    newBlock: ContentBlock;
    newSelection: SelectionState;
    newEditorState: EditorState;
};
export declare type TextDirection = 'rtl' | 'ltr' | 'auto';
export declare const isTextDirection: (dir: string) => dir is TextDirection;
export declare type TextAlignment = 'left' | 'center' | 'right' | 'justify';
export declare type InlineStyle = 'bold' | 'underline' | 'italic' | 'spoiler' | 'not_bold' | 'not_italic' | 'not_underline';
export declare type onAtomicBlockFocus = (params: {
    blockKey?: string;
    type?: string;
    data?: RicosEntity['data'];
}) => void;
export interface SEOSettings {
    paywall?: {
        className?: string;
        index?: number;
    };
}
interface CommonContextType {
    theme: RichContentTheme;
    t: TranslationFunction;
    locale: string;
    localeContent?: string;
    anchorTarget?: AnchorTarget;
    relValue?: RelValue;
    customAnchorScroll?: CustomAnchorScroll;
    helpers: Helpers;
    isMobile: boolean;
    iframeSandboxDomain?: string;
}
export interface EditorContextType extends CommonContextType {
    config: LegacyEditorPluginConfig;
    setEditorState: (editorState: EditorState) => void;
    getEditorState: () => EditorState;
    getEditorBounds: GetEditorBounds;
    languageDir: TextDirection;
    shouldRenderOptimizedImages?: boolean;
    siteDomain?: string;
    setInPluginEditingMode: (shouldEnable: boolean) => void;
    getInPluginEditingMode: () => boolean;
    innerModal: InnerModalType;
    renderInnerRCE: (params: any) => JSX.Element;
    innerRCERenderedIn?: string;
    disableKeyboardEvents?: (shouldEnable: boolean) => void;
    experiments?: AvailableExperiments;
    textWrap: boolean;
    onKeyboardShortcutClick: OnKeyboardShortcutClick;
}
export interface ViewerContextType extends CommonContextType {
    config: LegacyViewerPluginConfig;
    disabled?: boolean;
    seoMode?: SEOSettings;
    disableRightClick?: boolean;
    contentState?: DraftContent;
    textAlignment?: 'left' | 'right';
    experiments?: AvailableExperiments;
}
export declare type Experiment = {
    enabled: boolean;
    value?: string;
    namespace?: string;
};
export declare type AvailableExperiments = Record<string, Experiment>;
export declare type LinkPreviewData = {
    title?: string;
    description?: string;
    thumbnail_url?: string;
    provider_url?: string;
    html?: string;
};
export declare type LinkDataUrl = {
    url: string;
    target?: string;
    rel?: string;
};
export declare type AddLinkData = LinkDataUrl & {
    anchor?: string;
};
export declare type OnKeyboardShortcutClick = (param: {
    buttonName: string;
    pluginId?: string;
}) => void;
//# sourceMappingURL=commonTypes.d.ts.map